California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 033 - EXPANDS LOCAL GOVERNMENTS' AUTHORITY TO ENACT RENT CONTROL ON RESIDENTIAL PROPERTY. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1297793 | DE LEON BELIEVING IN A BETTER CALIFORNIA BALLOT MEASURE COMMITTEE - YES ON PROPOSITIONS 3, 32 AND 33; KEVIN | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1406018 | CALIFORNIANS FOR AFFORDABLE HOUSING, SPONSORED BY THE CALIFORNIA RENTAL HOUSING ASSOCIATION | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1400190 | HOMEOWNERSHIP FOR FAMILIES SPONSORED BY CALIFORNIA ASSOCIATION OF REALTORS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1469388 | CALIFORNIA AFFORDABLE RENTAL HOUSING COALITION, NO ON PROPOSITION ___ | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1458912 | RENTERS AND HOMEOWNERS FOR RENT CONTROL YES ON 33, SPONSORED BY AIDS HEALTHCARE FOUNDATION | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1462983 | NO ON PROP 33, CALIFORNIANS TO PROTECT AFFORDABLE HOUSING A COALITION OF HOUSING ADVOCATES, RENTERS, BUSINESSES, TAXPAYERS, AND VETERANS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1421884 | NO ON 33, CALIFORNIANS FOR RESPONSIBLE HOUSING: A BI-PARTISAN COALITION OF AFFORDABLE HOUSING ADVOCATES, TAXPAYERS, VETERANS, AND SMALL BUSINESSES, SPONSORED BY CALIFORNIA APARTMENT ASSOCIATION | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1405723 | ISSUES PAC OF APARTMENT ASSOCIATION OF GREATER LOS ANGELES | OPPOSE